Utilities
=========

A package of useful utilities for `CGExplore`.


Host-guest conformer generation using SpinDry
---------------------------------------------

.. toctree::
  :maxdepth: 1

  get_supramolecule <_autosummary/cgexplore.utilities.get_supramolecule>

Optimisation
------------

.. toctree::
  :maxdepth: 1

  optimise_ligand <_autosummary/cgexplore.utilities.optimise_ligand>
  run_constrained_optimisation <_autosummary/cgexplore.utilities.run_constrained_optimisation>
  run_optimisation <_autosummary/cgexplore.utilities.run_optimisation>
  run_soft_md_cycle <_autosummary/cgexplore.utilities.run_soft_md_cycle>
  shift_beads <_autosummary/cgexplore.utilities.shift_beads>
  soften_forcefield <_autosummary/cgexplore.utilities.soften_forcefield>
  yield_near_models <_autosummary/cgexplore.utilities.yield_near_models>
  yield_shifted_models <_autosummary/cgexplore.utilities.yield_shifted_models>

Visualisation
-------------

.. toctree::
  :maxdepth: 1

  Pymol <_autosummary/cgexplore.utilities.Pymol>
  draw_pie <_autosummary/cgexplore.utilities.draw_pie>
  add_text_to_ax <_autosummary/cgexplore.utilities.add_text_to_ax>
  add_structure_to_ax <_autosummary/cgexplore.utilities.add_structure_to_ax>

